#ifndef QRK_FIND_FILES_H
#define QRK_FIND_FILES_H

/*!
  \file
  \brief fBNgȉ̃t@CTs

  \author Satofumi KAMIMURA

  $Id: findFiles.h 1663 2010-02-01 07:17:58Z satofumi $
*/

#include <boost/xpressive/xpressive.hpp>
#include <vector>
#include <string>


namespace qrk
{
  /*!
    fBNgȉ̃t@CTs

    \param[out] files tt@C
    \param[in] root_path T̃[gfBNg
    \param[in] pattern t@Čp^[

    \return tt@C
  */
  extern size_t findFiles(std::vector<std::string>& files,
                          const char* root_path,
                          const boost::xpressive::sregex pattern);
}

#endif /* !QRK_FIND_FILES_H */
